/*******************************************************************************
* File Name: testI2CPin.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "testI2CPin.h"

static testI2CPin_BACKUP_STRUCT  testI2CPin_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: testI2CPin_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet testI2CPin_SUT.c usage_testI2CPin_Sleep_Wakeup
*******************************************************************************/
void testI2CPin_Sleep(void)
{
    #if defined(testI2CPin__PC)
        testI2CPin_backup.pcState = testI2CPin_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            testI2CPin_backup.usbState = testI2CPin_CR1_REG;
            testI2CPin_USB_POWER_REG |= testI2CPin_USBIO_ENTER_SLEEP;
            testI2CPin_CR1_REG &= testI2CPin_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(testI2CPin__SIO)
        testI2CPin_backup.sioState = testI2CPin_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        testI2CPin_SIO_REG &= (uint32)(~testI2CPin_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: testI2CPin_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to testI2CPin_Sleep() for an example usage.
*******************************************************************************/
void testI2CPin_Wakeup(void)
{
    #if defined(testI2CPin__PC)
        testI2CPin_PC = testI2CPin_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            testI2CPin_USB_POWER_REG &= testI2CPin_USBIO_EXIT_SLEEP_PH1;
            testI2CPin_CR1_REG = testI2CPin_backup.usbState;
            testI2CPin_USB_POWER_REG &= testI2CPin_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(testI2CPin__SIO)
        testI2CPin_SIO_REG = testI2CPin_backup.sioState;
    #endif
}


/* [] END OF FILE */
